module Spree
  module OrderDecorator
    def self.prepended(base)
      base.scope :abandoned, -> do
        incomplete.
        where('email IS NOT NULL')
        where('item_count > 0').
        where("updated_at < ?", Time.current - SolidusAbandonedCarts::Config.abandoned_after_minutes.minutes)
      end

      base.scope :abandon_not_notified, -> do
        abandoned.where(abandoned_cart_email_sent_at: nil)
      end
    end

    def abandoned_cart_actions
      Spree::Config.abandoned_cart_mailer_class.abandoned_cart_email(self).deliver_now
      touch(:abandoned_cart_email_sent_at)
    end

    def last_for_user?
      Spree::Order.where(email: email).where('id > ?', id).none?
    end
  end
end

Spree::Order.prepend Spree::OrderDecorator
